==> interceptable-0.1.0.tar.gz: lib/src/builder/collector/interceptable_collector.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:crypto/crypto.dart' as crypto;
import 'package:analyzer/dart/element/element.dart' as an;
import 'package:build/build.dart';
import 'package:interceptable/interceptable.dart';
import 'package:interceptable/src/builder/object/cache_object.dart';
import 'package:interceptable/src/builder/util/cache_utils.dart';
import 'package:source_gen/source_gen.dart';
import 'package:renderable/renderable.dart';

class InterceptableCollector extends GeneratorForAnnotation<MakeInterceptable> {
  static Map<String, bool> firstCheck = {};

  static Map<int, String> idPrefixDict = {};

  @override
  generateForAnnotatedElement(
    an.Element element,
    ConstantReader annotation,
    BuildStep buildStep,
  ) {
    String filePath = buildStep.inputId.uri.toString();
    List<ImportElement> imports =
        firstCheck[buildStep.inputId.uri.toString()] == true
            ? []
            : element.library.imports
                .map(AnalyzerElementConverter(element.library.id).parseImport)
                .where((e) => e != null)
                .toList();

    firstCheck[buildStep.inputId.uri.toString()] = true;

    var class_ =
        AnalyzerElementConverter(element.library.id).parseClass(element);

    // modify
    imports.add(ImportElement(path: buildStep.inputId.uri.toString()));

    String originalName = class_.name;
    class_.name = "\$$originalName";
    class_.supertype.name = originalName;
    class_.supertype.prefix = null;
    class_.supertype.typeParameters = class_.typeParameters;
    // change field to accessors
    class_.fields.forEach((e) {
      e.isSynthetic = true;
      e.getter.isSynthetic = false;
      e.setter.isSynthetic = false;
      e.getter.body = FunctionBody(statements: [
        RawStatement(
          "return Interceptable.applyGetterInterceptor(this, $originalName, \"${e.name}\", super.${e.name});",
        ),
      ]);

      e.setter.body = FunctionBody(statements: [
        RawStatement(
          "super.${e.name} = Interceptable.applySetterInterceptor(this, $originalName, \"${e.name}\", ${e.setter.parameters.first.name});",
        ),
      ]);
    });

    class_.methods.forEach((e) {
      var statementString =
          "Interceptable.applyMethodInterceptor(this, $originalName, \"${e.name}\", super.${e.name})";
      if (e.returnType.name == "void") {
        e.body = FunctionBody(
          statements: [
            RawStatement(statementString + ";"),
          ],
        );
        return;
      }
      e.body = FunctionBody(
        returnStatement: ReturnStatement(
          returnValue: RawStatement(statementString),
        ),
      );
    });

    // generation
    String generatedFileName =
        crypto.md5.convert(Utf8Encoder().convert(filePath)).toString();
    String generatedFilePackagePath =
        "package:${buildStep.inputId.package}/generated/$generatedFileName.dart";
    String generatedFilePath =
        "${Directory.current.path}/lib/generated/$generatedFileName.dart";

    String code = FileElement(
      filePath:
          "${Directory.current.path}/lib/generated/$generatedFileName.dart",
      imports: imports,
      renders: [
        RawStatement("export \"$filePath\";"),
        class_,
      ],
    ).render();

    return CacheUtils.encode(json.encode(
      CacheObject(
        generatedFilePackagePath,
        generatedFilePath,
        originalName,
        "\$$originalName",
        code,
      ),
    ));
  }
}

==> interceptable-0.2.0.tar.gz: lib/src/builder/collector/interceptable_collector.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:crypto/crypto.dart' as crypto;
import 'package:analyzer/dart/element/element.dart' as an;
import 'package:build/build.dart';
import 'package:interceptable/src/annotation/interceptable.dart';
import 'package:interceptable/src/builder/object/cache_object.dart';
import 'package:interceptable/src/builder/util/cache_utils.dart';
import 'package:source_gen/source_gen.dart';
import 'package:renderable/renderable.dart';

class InterceptableCollector extends GeneratorForAnnotation<UseInterceptable> {
  static Map<String, bool> firstCheck = {};

  static Map<int, String> idPrefixDict = {};

  @override
  generateForAnnotatedElement(
    an.Element element,
    ConstantReader annotation,
    BuildStep buildStep,
  ) {
    String filePath = buildStep.inputId.uri.toString();
    List<ImportElement> imports =
        firstCheck[buildStep.inputId.uri.toString()] == true
            ? []
            : element.library.imports
                .map(AnalyzerElementConverter(element.library.id).parseImport)
                .where((e) => e != null)
                .toList();

    firstCheck[buildStep.inputId.uri.toString()] = true;

    var class_ =
        AnalyzerElementConverter(element.library.id).parseClass(element);

    // modify
    imports.add(ImportElement(path: buildStep.inputId.uri.toString()));

    String originalName = class_.name;
    class_.name = "\$$originalName";
    class_.supertype.name = originalName;
    class_.supertype.prefix = null;
    class_.supertype.typeParameters = class_.typeParameters;
    // change field to accessors
    class_.fields.forEach((e) {
      e.isSynthetic = true;
      e.getter.isSynthetic = false;
      e.setter.isSynthetic = false;
      e.getter.body = FunctionBody(statements: [
        RawStatement(
          "return Interceptable.applyGetterInterceptor(this, $originalName, \"${e.name}\", super.${e.name});",
        ),
      ]);

      e.setter.body = FunctionBody(statements: [
        RawStatement(
          "super.${e.name} = Interceptable.applySetterInterceptor(this, $originalName, \"${e.name}\", ${e.setter.parameters.first.name});",
        ),
      ]);
    });

    class_.methods.forEach((e) {
      var statementString =
          "Interceptable.applyMethodInterceptor(this, $originalName, \"${e.name}\", super.${e.name})";
      if (e.returnType.name == "void") {
        e.body = FunctionBody(
          statements: [
            RawStatement(statementString + ";"),
          ],
        );
        return;
      }
      e.body = FunctionBody(
        returnStatement: ReturnStatement(
          returnValue: RawStatement(statementString),
        ),
      );
    });

    // generation
    String generatedFileName =
        crypto.md5.convert(Utf8Encoder().convert(filePath)).toString();
    String generatedFilePackagePath =
        "package:${buildStep.inputId.package}/generated/$generatedFileName.dart";
    String generatedFilePath =
        "${Directory.current.path}/lib/generated/$generatedFileName.dart";

    String code = FileElement(
      filePath:
          "${Directory.current.path}/lib/generated/$generatedFileName.dart",
      imports: imports,
      renders: [
        RawStatement("export \"$filePath\";"),
        class_,
      ],
    ).render();

    return CacheUtils.encode(json.encode(
      CacheObject(
        generatedFilePackagePath,
        generatedFilePath,
        originalName,
        "\$$originalName",
        code,
      ),
    ));
  }
}
